@@ -1,5 +1,4 @@
 import unittest
-from mindsdb_native import F
 from common import DB_CREDENTIALS, break_dataset
 
 
@@ -30,8 +29,6 @@ class TestMariaDB(unittest.TestCase):
 
         assert len(maria_ds) <= LIMIT
 
-        F.analyse_dataset(from_data=maria_ds)
-
         # Our SQL parsing succeds here, but the query fails, test if we're still able to filter via the dataframe fallback
         maria_ds._query = maria_ds._query.replace(self.TABLE, 'wrongly_named_table')
         assert len(maria_ds.filter([['Population', '<', 33098932]], 8)) == 8
